@@ -6,20 +6,23 @@ from svarga.utils import urljoin
 from svargaext.transform import render, abspats, deglob, backends
 
 @template.global_
-def transform(backend, name, path):
+def transform(backend, name, path, version=True):
     mapping = env.settings.TRANSFORM[backend][name]
     for source, target in mapping.items():
         if path == source or fnmatch.fnmatch(path, source):
             pth, src, tgt = abspats(name, path, source, target)
-            render(backend, pth, deglob(pth, src, tgt))
+            ver = render(backend, pth, deglob(pth, src, tgt))
 
             url = env.get_static_url(name)
-            return urljoin.safe_url_join(url, deglob(path, source, target))
+            fullurl = urljoin.safe_url_join(url, deglob(path, source, target))
+            if version:
+                fullurl += '?v=' + hex(int(ver))[2:]
+            return fullurl
     raise Exception("Can't find path %s in %s" % (path, name))
 
 def specific_global(backend):
-    def inner(name, path):
-        return transform(backend, name, path)
+    def inner(name, path, version=True):
+        return transform(backend, name, path, version=version)
     inner.__name__ = backend
     return inner
 
